@@ -25,6 +25,7 @@
 #define IO_H
 
 #include <sys/time.h>
+#include <linux/atmdev.h>
 #include "asn_incl.h"
 #include "rfc1155_smi.h"
 #include "rfc1157_snmp.h"
@@ -37,5 +38,6 @@ int wait_for_message(int fd, struct timeval *timeout);
 int read_message(int fd, Message *message);
 int send_message(int fd, Message *message);
 int open_ilmi(int itf,const char *qos_spec);
+int get_ci_range(struct atm_cirange *ci);
 
 #endif
