@@ -1,6 +1,6 @@
 /* sap.h - SAP manipulations */
 
-/* Written 1996-1998 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1996-1999 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #ifndef SAP_H
@@ -22,7 +22,7 @@ int sap_compat(const struct sockaddr_atmsvc *old_addr,
   struct atm_sap *res_sap,const struct atm_qos *old_qos,
   const struct atm_qos *new_qos,struct atm_qos *res_qos);
 int sap_encode(Q_DSC *dsc,const struct sockaddr_atmsvc *addr,
-  const struct atm_sap *sap,const struct atm_qos *qos,int uni);
+  const struct atm_sap *sap,const struct atm_qos *qos,int uni,int max_rate);
 
 /*
  * sap_encode returns zero on success, -errno on error.
